@@ -34,11 +34,6 @@ using namespace Akonadi;
 
 QTEST_AKONADIMAIN(AutoIncrementTest)
 
-static bool isMySQLEnvironment()
-{
-    return (qgetenv("TESTRUNNER_DB_ENVIRONMENT") == "mysql");
-}
-
 void AutoIncrementTest::initTestCase()
 {
     AkonadiTest::checkTestIsIsolated();
@@ -97,10 +92,6 @@ void AutoIncrementTest::testItemAutoIncrement()
     AKVERIFYEXEC(job);
     Item newItem = job->item();
 
-    if (isMySQLEnvironment()) {
-        QEXPECT_FAIL("", "Server bug: http://bugs.mysql.com/bug.php?id=199", Continue);
-    }
-
     QVERIFY(newItem.id() > lastId);
     lastId = newItem.id();
 }
@@ -134,10 +125,6 @@ void AutoIncrementTest::testCollectionAutoIncrement()
     AKVERIFYEXEC(job);
     Collection newCollection = job->collection();
 
-    if (isMySQLEnvironment()) {
-        QEXPECT_FAIL("", "Server bug: http://bugs.mysql.com/bug.php?id=199", Continue);
-    }
-
     QVERIFY(newCollection.id() > lastId);
     lastId = newCollection.id();
 }
