@@ -117,6 +117,16 @@ void AgentInstance::synchronizeCollectionTree()
     AgentManager::self()->d->synchronizeCollectionTree(*this);
 }
 
+void AgentInstance::synchronizeTags()
+{
+    AgentManager::self()->d->synchronizeTags(*this);
+}
+
+void AgentInstance::synchronizeRelations()
+{
+    AgentManager::self()->d->synchronizeRelations(*this);
+}
+
 AgentInstance &AgentInstance::operator=(const AgentInstance &other)
 {
     if (this != &other) {
