@@ -157,7 +157,7 @@ void ItemSyncPrivate::checkDone()
         //and wait until the transaction is committed to process the next batch
         if (mTransactionMode == ItemSync::MultipleTransactions || (mDeliveryDone && mRemoteItemQueue.isEmpty())) {
             if (mCurrentTransaction) {
-                emit q->transactionCommitted();
+                Q_EMIT q->transactionCommitted();
                 mCurrentTransaction->commit();
                 mCurrentTransaction = nullptr;
             }
@@ -165,15 +165,23 @@ void ItemSyncPrivate::checkDone()
         }
     }
     mProcessingBatch = false;
+
+    if (q->error() == Job::UserCanceled && mTransactionJobs == 0 && !mFinished) {
+        qCDebug(AKONADICORE_LOG) << "ItemSync of collection" << mSyncCollection.id() << "finished due to user cancelling";
+        mFinished = true;
+        q->emitResult();
+        return;
+    }
+
     if (!mRemoteItemQueue.isEmpty()) {
         execute();
         //We don't have enough items, request more
         if (!mProcessingBatch) {
-            emit q->readyForNextBatch(mBatchSize - mRemoteItemQueue.size());
+            Q_EMIT q->readyForNextBatch(mBatchSize - mRemoteItemQueue.size());
         }
         return;
     }
-    emit q->readyForNextBatch(mBatchSize);
+    Q_EMIT q->readyForNextBatch(mBatchSize);
 
     if (allProcessed() && !mFinished) {
         // prevent double result emission, can happen since checkDone() is called from all over the place
@@ -211,9 +219,9 @@ void ItemSync::setFullSyncItems(const Item::List &items)
     }
     d->mRemoteItemQueue += items;
     d->mTotalItemsProcessed += items.count();
-    qCDebug(AKONADICORE_LOG) << "Received: " << items.count()
-                             << "In total: " << d->mTotalItemsProcessed
-                             << " Wanted: " << d->mTotalItems;
+    qCDebug(AKONADICORE_LOG) << "Received batch: " << items.count()
+                             << "Already processed: " << d->mTotalItemsProcessed
+                             << "Expected total amount: " << d->mTotalItems;
     if (!d->mDisableAutomaticDeliveryDone && (d->mTotalItemsProcessed == d->mTotalItems)) {
         d->mDeliveryDone = true;
     }
@@ -226,7 +234,7 @@ void ItemSync::setTotalItems(int amount)
     Q_ASSERT(!d->mIncremental);
     Q_ASSERT(amount >= 0);
     setStreamingEnabled(true);
-    qCDebug(AKONADICORE_LOG) << amount;
+    qCDebug(AKONADICORE_LOG) << "Expected total amount:" << amount;
     d->mTotalItems = amount;
     setTotalAmount(KJob::Bytes, amount);
     if (!d->mDisableAutomaticDeliveryDone && (d->mTotalItems == 0)) {
@@ -363,9 +371,14 @@ void ItemSyncPrivate::execute()
 //process the current batch of items
 void ItemSyncPrivate::processBatch()
 {
+    Q_Q(ItemSync);
     if (mCurrentBatchRemoteItems.isEmpty() && !mDeliveryDone) {
         return;
     }
+    if (q->error() == Job::UserCanceled) {
+        checkDone();
+        return;
+    }
 
     //request a transaction, there are items that require processing
     requestTransaction();
@@ -517,7 +530,7 @@ void ItemSync::rollback()
     if (d->mCurrentTransaction) {
         d->mCurrentTransaction->rollback();
     }
-    d->mDeliveryDone = true; // user wont deliver more data
+    d->mDeliveryDone = true; // user won't deliver more data
     d->execute(); // end this in an ordered way, since we have an error set no real change will be done
 }
 
