@@ -362,7 +362,7 @@ void Akonadi::FavoriteCollectionsModel::setFavoriteLabel(const Collection &colle
     }
 
     const QModelIndex index = mapFromSource(idx);
-    emit dataChanged(index, index);
+    Q_EMIT dataChanged(index, index);
 }
 
 QVariant Akonadi::FavoriteCollectionsModel::data(const QModelIndex &index, int role) const
@@ -484,7 +484,7 @@ Qt::ItemFlags FavoriteCollectionsModel::flags(const QModelIndex &index) const
 void FavoriteCollectionsModel::pasteJobDone(KJob *job)
 {
     if (job->error()) {
-        qCDebug(AKONADICORE_LOG) << job->errorString();
+        qCDebug(AKONADICORE_LOG) << "Paste job error:" << job->errorString();
     }
 }
 
