@@ -47,11 +47,7 @@ SessionThread::SessionThread(QObject *parent)
 
 SessionThread::~SessionThread()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     QMetaObject::invokeMethod(this, &SessionThread::doThreadQuit, Qt::QueuedConnection);
-#else
-    QMetaObject::invokeMethod(this, "doThreadQuit", Qt::QueuedConnection);
-#endif
     if (!thread()->wait(10 * 1000)) {
         thread()->terminate();
         // Make sure to wait until it's done, otherwise it can crash when the pthread callback is called
