@@ -54,11 +54,7 @@ AkThread::~AkThread()
 void AkThread::startThread()
 {
     Q_ASSERT(m_startMode != NoThread);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     const bool init = QMetaObject::invokeMethod(this, &AkThread::init, Qt::QueuedConnection);
-#else
-    const bool init = QMetaObject::invokeMethod(this, "init", Qt::QueuedConnection);
-#endif
     Q_ASSERT(init);
     Q_UNUSED(init);
 }
@@ -68,11 +64,7 @@ void AkThread::quitThread()
     if (m_startMode == NoThread)
         return;
     qCDebug(AKONADISERVER_LOG) << "Shutting down" << objectName() << "...";
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     const bool invoke = QMetaObject::invokeMethod(this, &AkThread::quit, Qt::QueuedConnection);
-#else
-    const bool invoke = QMetaObject::invokeMethod(this, "quit", Qt::QueuedConnection);
-#endif
 
     Q_ASSERT(invoke);
     Q_UNUSED(invoke);
